@@ -515,7 +515,7 @@ static void init(struct options *const o, struct progstate *const state)
       state->ifd = open(o->i, O_RDWR);
     }
     else {
-      if (strchr(o->i, ':'))
+      if (strchr(o->i, ':') && !strchr(o->I, 'N'))
 	state->ifd = open_tcp(o, O_RDONLY);
       else
 	state->ifd = open(o->i, O_RDONLY);
@@ -550,7 +550,7 @@ static void init(struct options *const o, struct progstate *const state)
 	exit(2);
       }
     }
-    if (strchr(o->o, ':'))
+    if (strchr(o->o, ':') && !strchr(o->O, 'N'))
       state->ofd = open_tcp(o, O_WRONLY);
     else {
       state->ofd = open(o->o, O_RDWR | O_CREAT | O_TRUNC, 0666);
@@ -860,7 +860,7 @@ static void loop(struct options *const o, struct progstate *const state)
 		 * read position */
   char *curbuf2; /* Iterate over buf when writing */
   int nbytes = 0; /* Just one system call read() */
-  int bytes_read = 0; /* Overall, both loops */
+  long long bytes_read = 0; /* Overall, both loops */
   int pipefd[2];
 
   state->pid = getpid();
@@ -1223,10 +1223,11 @@ static void usage(void)
 	  "         to use stdin, use -i ''\n"
 	  "-o <s> = name of output file, - = just sink data\n"
 	  "         to use stdout, -o ''\n"
-	  "-I <c> = Type of input file\n"
-	  "-O <c> = Type of ouput file\n"
+	  "-I <s> = Type of input file\n"
+	  "-O <s> = Type of ouput file\n"
           "         'f' = fifo (create it)\n"
           "         'a' = set audio modes on file (i.e. CD quality)\n"
+          "         'N' = don't use TCP even if filename has ':'\n"
           "         't' = tee - in addition to outfile, "
 	  "copy stream to fd 3\n"
 	  "         [Multiple chars allowed]\n"
